Stan Math Library: Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Static Public Member Functions | List of all members
Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor > Struct Template Reference

`#include <Eigen_NumTraits.hpp>`

## Public Types
typedef stan::math::var | LhsScalar
typedef stan::math::var | RhsScalar
typedef scalar_product_traits< LhsScalar, RhsScalar >::ReturnType | ResScalar

## Static Public Member Functions
static void | run (Index rows, Index cols, Index depth, const LhsScalar *_lhs, Index lhsStride, const RhsScalar *_rhs, Index rhsStride, ResScalar *res, Index resStride, const ResScalar &alpha, level3_blocking< LhsScalar, RhsScalar > &, GemmParallelInfo< Index > *)

## Detailed Description

### template<typename Index, int LhsStorageOrder, bool ConjugateLhs, int RhsStorageOrder, bool ConjugateRhs>
struct Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >

Definition at line 186 of file Eigen_NumTraits.hpp.

## Member Typedef Documentation

template<typename Index , int LhsStorageOrder, bool ConjugateLhs, int RhsStorageOrder, bool ConjugateRhs>

typedef stan::math::var Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >::LhsScalar

Definition at line 190 of file Eigen_NumTraits.hpp.

template<typename Index , int LhsStorageOrder, bool ConjugateLhs, int RhsStorageOrder, bool ConjugateRhs>

typedef scalar_product_traits<LhsScalar, RhsScalar>::ReturnType Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >::ResScalar

Definition at line 193 of file Eigen_NumTraits.hpp.

template<typename Index , int LhsStorageOrder, bool ConjugateLhs, int RhsStorageOrder, bool ConjugateRhs>

typedef stan::math::var Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >::RhsScalar

Definition at line 191 of file Eigen_NumTraits.hpp.

## Member Function Documentation

template<typename Index , int LhsStorageOrder, bool ConjugateLhs, int RhsStorageOrder, bool ConjugateRhs>

static void Eigen::internal::general_matrix_matrix_product< Index, stan::math::var, LhsStorageOrder, ConjugateLhs, stan::math::var, RhsStorageOrder, ConjugateRhs, ColMajor >::run | ( | Index | rows,
|  | Index | cols,
|  | Index | depth,
|  | const LhsScalar * | _lhs,
|  | Index | lhsStride,
|  | const RhsScalar * | _rhs,
|  | Index | rhsStride,
|  | ResScalar * | res,
|  | Index | resStride,
|  | const ResScalar & | alpha,
|  | level3_blocking< LhsScalar, RhsScalar > & | ,
|  | GemmParallelInfo< Index > * |
| ) |  |
| inlinestatic

Definition at line 194 of file Eigen_NumTraits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/mat/fun/Eigen_NumTraits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.